@@ -630,6 +630,8 @@ class WordToken(models.Model):
                 break
             context.append(prev)
             prev = prev.getPreviousWord()
+            if prev is None:
+                break
             durSum += prev.getDuration()
         return reversed(context)
 
@@ -642,6 +644,8 @@ class WordToken(models.Model):
                 break
             context.append(foll)
             foll = foll.getFollowingWord()
+            if foll is None:
+                break
             durSum += foll.getDuration()
         return context
 
@@ -834,6 +838,8 @@ class WordToken(models.Model):
         return True
 
     def getAnalysisLines(self,form):
+        if settings.DEBUG:
+            self.createPictures()
         beg,end,vow,prevSound,follSound = self.getAcousticInfo()
         outline = {'Word':self.WordType.Label}
         outline['Vowel'] = self.WordType.getStressVowel()
