@@ -261,18 +261,18 @@ def combineResults(allout):
 @task()
 def AnalyzeSpeaker(baseqs,speakNum,form):
     words = baseqs.filter(Dialog__Speaker__Number = speakNum)
-    cur = ''
+    #cur = ''
     allout = []
-    logger.info(speakNum)
-    logger.info(str(len(words)))
+    #logger.info(speakNum)
+    #logger.info(str(len(words)))
     #updatelogfile(logfilename, str(len(words)))
     for w in words:
         if not w.isAcceptable():
             continue
         #if str(w.Dialog) == 's2003' or str(w.Dialog) =='s4001':
         #    continue
-        if cur != str(w.Dialog):
-            cur = str(w.Dialog)
+        #if cur != str(w.Dialog):
+        #    cur = str(w.Dialog)
             #updatelogfile(logfilename, cur)
         allout.extend(w.getAnalysisLines(form))
     return allout
